@@ -61,7 +61,7 @@ folderGreenClosed22.src='/style/Crystal/22/html-menu-treeview/folder_green.png';
 var folderRedClosed22 = new Image(22,22);
 folderRedClosed22.src='/style/Crystal/22/html-menu-treeview/folder_red.png';
 var folderViolet22 = new Image(22,22);
-folderViolet22.src='/style/Crystal/22/html-menu-treeview/folderViolet.gif';
+folderViolet22.src='/style/Crystal/22/html-menu-treeview/folder_violet.png';
 var folderYellowClosed22 = new Image(22,22);
 folderYellowClosed22.src='/style/Crystal/22/html-menu-treeview/folder_yellow.png';
 var folderOrangeClosed22 = new Image(22,22);
@@ -87,7 +87,7 @@ folderGreenClosed32.src='/style/Crystal/32/html-menu-treeview/folder_green.png';
 var folderRedClosed32 = new Image(32,32);
 folderRedClosed32.src='/style/Crystal/32/html-menu-treeview/folder_red.png';
 var folderViolet32 = new Image(32,32);
-folderViolet32.src='/style/Crystal/32/html-menu-treeview/folderViolet.gif';
+folderViolet32.src='/style/Crystal/32/html-menu-treeview/folder_violet.png';
 var folderYellowClosed32 = new Image(32,32);
 folderYellowClosed32.src='/style/Crystal/32/html-menu-treeview/folder_yellow.png';
 var folderOrangeClosed32 = new Image(32,32);
@@ -99,7 +99,7 @@ folderHtmlClosed32.src='/style/Crystal/32/html-menu-treeview/folder_html.png';
 var folderFavoriteClosed32 = new Image(32,32);
 folderFavoriteClosed32.src='/style/Crystal/32/html-menu-treeview/folder_favorite.png';
 var folderTextClosed32 = new Image(32,32);
-folderTextClosed32.src='/style/Crystal/32/html-menu-treeview/folder_text.png';
+folderTextClosed32.src='/style/Crystal/32/html-menu-treeview/folder_txt.png';
 var folderLockedClosed32 = new Image(32,32);
 folderLockedClosed32.src='/style/Crystal/32/html-menu-treeview/folder_locked.png';
 var folderCrystalClosed32 = new Image(32,32);
@@ -135,7 +135,7 @@ folderGreenClosed48.src='/style/Crystal/48/html-menu-treeview/folder_green.png';
 var folderRedClosed48 = new Image(48,48);
 folderRedClosed48.src='/style/Crystal/48/html-menu-treeview/folder_red.png';
 var folderViolet48 = new Image(48,48);
-folderViolet48.src='/style/Crystal/48/html-menu-treeview/folderViolet.gif';
+folderViolet48.src='/style/Crystal/48/html-menu-treeview/folder_violet.png';
 var folderYellowClosed48 = new Image(48,48);
 folderYellowClosed48.src='/style/Crystal/48/html-menu-treeview/folder_yellow.png';
 var folderOrangeClosed48 = new Image(48,48);
@@ -147,7 +147,7 @@ folderHtmlClosed48.src='/style/Crystal/48/html-menu-treeview/folder_html.png';
 var folderFavoriteClosed48 = new Image(48,48);
 folderFavoriteClosed48.src='/style/Crystal/48/html-menu-treeview/folder_favorite.png';
 var folderTextClosed48 = new Image(48,48);
-folderTextClosed48.src='/style/Crystal/48/html-menu-treeview/folder_text.png';
+folderTextClosed48.src='/style/Crystal/48/html-menu-treeview/folder_txt.png';
 var folderLockedClosed48 = new Image(48,48);
 folderLockedClosed48.src='/style/Crystal/48/html-menu-treeview/folder_locked.png';
 var folderCrystalClosed48 = new Image(48,48);
@@ -183,7 +183,7 @@ folderGreenClosed64.src='/style/Crystal/64/html-menu-treeview/folder_green.png';
 var folderRedClosed64 = new Image(64,64);
 folderRedClosed64.src='/style/Crystal/64/html-menu-treeview/folder_red.png';
 var folderViolet64 = new Image(64,64);
-folderViolet64.src='/style/Crystal/64/html-menu-treeview/folderViolet.gif';
+folderViolet64.src='/style/Crystal/64/html-menu-treeview/folder_violet.png';
 var folderYellowClosed64 = new Image(64,64);
 folderYellowClosed64.src='/style/Crystal/64/html-menu-treeview/folder_yellow.png';
 var folderOrangeClosed64 = new Image(64,64);
@@ -195,7 +195,7 @@ folderHtmlClosed64.src='/style/Crystal/64/html-menu-treeview/folder_html.png';
 var folderFavoriteClosed64 = new Image(64,64);
 folderFavoriteClosed64.src='/style/Crystal/64/html-menu-treeview/folder_favorite.png';
 var folderTextClosed64 = new Image(64,64);
-folderTextClosed64.src='/style/Crystal/64/html-menu-treeview/folder_text.png';
+folderTextClosed64.src='/style/Crystal/64/html-menu-treeview/folder_txt.png';
 var folderLockedClosed64 = new Image(64,64);
 folderLockedClosed64.src='/style/Crystal/64/html-menu-treeview/folder_locked.png';
 var folderCrystalClosed64 = new Image(64,64);
@@ -231,7 +231,7 @@ folderGreenClosed128.src='/style/Crystal/128/html-menu-treeview/folder_green.png
 var folderRedClosed128 = new Image(128,128);
 folderRedClosed128.src='/style/Crystal/128/html-menu-treeview/folder_red.png';
 var folderViolet128 = new Image(128,128);
-folderViolet128.src='/style/Crystal/128/html-menu-treeview/folderViolet.gif';
+folderViolet128.src='/style/Crystal/128/html-menu-treeview/folder_violet.png';
 var folderYellowClosed128 = new Image(128,128);
 folderYellowClosed128.src='/style/Crystal/128/html-menu-treeview/folder_yellow.png';
 var folderOrangeClosed128 = new Image(128,128);
@@ -243,7 +243,7 @@ folderHtmlClosed128.src='/style/Crystal/128/html-menu-treeview/folder_html.png';
 var folderFavoriteClosed128 = new Image(128,128);
 folderFavoriteClosed128.src='/style/Crystal/128/html-menu-treeview/folder_favorite.png';
 var folderTextClosed128 = new Image(128,128);
-folderTextClosed128.src='/style/Crystal/128/html-menu-treeview/folder_text.png';
+folderTextClosed128.src='/style/Crystal/128/html-menu-treeview/folder_txt.png';
 var folderLockedClosed128 = new Image(128,128);
 folderLockedClosed128.src='/style/Crystal/128/html-menu-treeview/folder_locked.png';
 var folderCrystalClosed128 = new Image(128,128);
